==> nextcloud-24.0.12.tgz: nextcloud/apps/notifications/l10n/zh_CN.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "你好 %s",
    "Hello %s," : "你好，%s",
    "_New notification for %s_::_%n new notifications for %s_" : ["%s 的 %n 条新通知"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["您有 %s 的 %n 条新通知"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "你可以更改这些邮件的频率或在<a href=\"%s\">设置</a>中禁用它们。",
    "You can change the frequency of these emails or disable them in the settings: %s" : "你可以更改这些邮件的频率或在设置中禁用它们：%s",
    "Admin notifications" : "管理员通知",
    "Notifications" : "通知",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "此应用为Nextcloud中已有的通知API提供后端和前端。",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "此应用为 Nextcloud 中已有的通知 API 提供后端和前端。\n\t\t这个 API 被其他应用使用来给 Web 界面及同步客户端中的用户发送通知和提醒。举一些例子：\n\n📬 联合云文件共享： 您收到一个新的远程共享\n\n📑 评论： 另一个用户在文件评论中提到了您\n\n🚢 更新通知： 应用或 Nextcloud 自身有可用更新\n\n📣 通知中心： 管理员发布了一个通知",
    "Failed to perform action" : "操作失败",
    "Dismiss" : "忽略",
    "Contact Nextcloud GmbH" : "联系 Nextcloud GmbH",
    "seconds ago" : "几秒前",
    "Failed to dismiss notification" : "无法清除通知",
    "in {path}" : "在 {path}",
    "Dismiss all notifications" : "忽略所有通知",
    "Requesting browser permissions to show notifications" : "请求浏览器权限以显示通知",
    "Push notifications might be unreliable" : "推送通知可能不可靠",
    "No notifications" : "没有通知",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "对于个人用户，Nextcloud GmbH 提供一个免费的推送网关。为保证良好的服务，网关对每个服务器发送的推送通知数量进行了限制。企业用户若需要更具扩展性的网关，请与 Nextcloud GmbH 联系以了解详情。",
    "Failed to dismiss all notifications" : "无法清除所有通知",
    "Send email reminders about unhandled notifications after:" : "多久之后发送电子邮件提醒未处理的通知：",
    "Play sound when a new notification arrives" : "收到新通知時播放提示音",
    "Play sound when a call started (requires Nextcloud Talk)" : "通话开始时播放提示音（需要 Nextcloud Talk）",
    "Never" : "永不",
    "1 hour" : "1 小时",
    "3 hours" : "3 小时 ",
    "1 day" : "1 天 ",
    "1 week" : "1 周 ",
    "Your settings have been updated." : "已更新设置",
    "An error occurred while updating your settings." : "更新设置时出错",
    "You need to set up your email address before you can receive notification emails." : "您需要设置您的电子邮件地址，然后才能收到通知电子邮件。"
},
"nplurals=1; plural=0;");

==> nextcloud-25.0.7.tgz: nextcloud/apps/notifications/l10n/zh_CN.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "你好 %s",
    "Hello %s," : "你好，%s",
    "_New notification for %s_::_%n new notifications for %s_" : ["%s 的 %n 条新通知"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["您有 %s 的 %n 条新通知"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "你可以更改这些邮件的频率或在<a href=\"%s\">设置</a>中禁用它们。",
    "You can change the frequency of these emails or disable them in the settings: %s" : "你可以更改这些邮件的频率或在设置中禁用它们：%s",
    "Admin notifications" : "管理员通知",
    "Notifications" : "通知",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "此应用为Nextcloud中已有的通知API提供后端和前端。",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "此应用为 Nextcloud 中已有的通知 API 提供后端和前端。\n\t\t这个 API 被其他应用使用来给 Web 界面及同步客户端中的用户发送通知和提醒。举一些例子：\n\n📬 联合云文件共享： 您收到一个新的远程共享\n\n📑 评论： 另一个用户在文件评论中提到了您\n\n🚢 更新通知： 应用或 Nextcloud 自身有可用更新\n\n📣 通知中心： 管理员发布了一个通知",
    "Failed to perform action" : "操作失败",
    "Dismiss" : "忽略",
    "Contact Nextcloud GmbH" : "联系 Nextcloud GmbH",
    "seconds ago" : "几秒前",
    "Failed to dismiss notification" : "清除通知失败",
    "in {path}" : "在 {path}",
    "Dismiss all notifications" : "忽略所有通知",
    "Requesting browser permissions to show notifications" : "请求浏览器权限以显示通知",
    "Push notifications might be unreliable" : "推送通知可能不可靠",
    "No notifications" : "没有通知",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "对于个人用户，Nextcloud GmbH 提供一个免费的推送网关。为保证良好的服务，网关对每个服务器发送的推送通知数量进行了限制。企业用户若需要更具扩展性的网关，请与 Nextcloud GmbH 联系以了解详情。",
    "Failed to dismiss all notifications" : "清除所有通知失败",
    "Send email reminders about unhandled notifications after:" : "多久之后发送电子邮件提醒未处理的通知：",
    "Play sound when a new notification arrives" : "收到新通知時播放提示音",
    "Play sound when a call started (requires Nextcloud Talk)" : "通话开始时播放提示音（需要Nextcloud通话应用）",
    "Never" : "永不",
    "1 hour" : "1 小时",
    "3 hours" : "3 小时 ",
    "1 day" : "1 天 ",
    "1 week" : "1 周 ",
    "Your settings have been updated." : "已更新设置",
    "An error occurred while updating your settings." : "更新设置时出错",
    "You need to set up your email address before you can receive notification emails." : "您需要设置您的电子邮件地址，然后才能收到通知电子邮件。"
},
"nplurals=1; plural=0;");
